CreateFFmpegParam class abstract

Constructors

CreateFFmpegParam({bool? log, String? corePath, String? mainName})
factory

Properties

corePath String?
Path URL of ffmpeg-core library.
no setter
hashCode int
The hash code for this object.
no setterinherited
log bool?
Whether Enable or Disable ffmpeg log to console.
no setter
mainName String?
Main name of ffmpeg-core library function.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited